@@ -314,10 +314,6 @@ class FlourishNodeAddView(flourish.form.AddForm):
         self.actions['add'].addClass('button-ok')
         self.actions['cancel'].addClass('button-cancel')
 
-    def updateWidgets(self):
-        super(FlourishNodeAddView, self).updateWidgets()
-        self.widgets['label'].maxlength = 7
-
     @z3c.form.button.buttonAndHandler(_('Submit'), name='add')
     def handleAdd(self, action):
         super(FlourishNodeAddView, self).handleAdd.func(self, action)
@@ -411,10 +407,6 @@ class NodeEditView(flourish.form.Form, z3c.form.form.EditForm):
         self.actions['apply'].addClass('button-ok')
         self.actions['cancel'].addClass('button-cancel')
 
-    def updateWidgets(self):
-        super(NodeEditView, self).updateWidgets()
-        self.widgets['label'].maxlength = 7
-
 
 class NodesTable(table.ajax.Table):
 
